@@ -16,7 +16,6 @@
 #include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
-#include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -104,10 +103,9 @@ properties_close_cb (GtkWidget *widget, gint arg, MultiloadApplet *ma)
 	{
 		case GTK_RESPONSE_HELP:
 
-		        gnome_help_display_on_screen (
-					"multiload", NULL,
-					gtk_widget_get_screen (GTK_WIDGET (
-							ma->applet)),
+			gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (ma->applet)),
+					"ghelp:multiload?multiload-prefs",
+					gtk_get_current_event_time (),
 					&error);
 
 			if (error) { /* FIXME: the user needs to see this */
@@ -345,7 +343,7 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
 	gtk_widget_show (vbox);
 	
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), vbox,
 			    TRUE, TRUE, 0);
 
 	categories_vbox = gtk_vbox_new (FALSE, 18);
@@ -639,9 +637,8 @@ fill_properties(GtkWidget *dialog, MultiloadApplet *ma)
 
 /* show properties dialog */
 void
-multiload_properties_cb (BonoboUIComponent *uic,
-			 MultiloadApplet   *ma,
-			 const char        *name)
+multiload_properties_cb (GtkAction       *action,
+			 MultiloadApplet *ma)
 {
 	GtkWidget *dialog = NULL;
 
@@ -668,7 +665,7 @@ multiload_properties_cb (BonoboUIComponent *uic,
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
+	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 
 	fill_properties(dialog, ma);
 
